@@ -28,7 +28,15 @@ sub create_grammar {
         qw(waflphrase asis wikilink a im mail tt b i del)
     ];
     my $all_blocks = [
-        qw(pre wafl_block hr hx waflparagraph ul ol blockquote table p empty)
+        qw(
+            pre wafl_block
+            hr hx
+            waflparagraph
+            ul ol
+            blockquote table
+            p empty
+            else
+        )
     ];
 
     return {
@@ -71,6 +79,15 @@ sub create_grammar {
             filter => sub { chomp },
         },
 
+        else => {
+            match => qr/^(.*)\n/,
+            phrases => [],
+            filter => sub {
+                my $node = shift;
+                $node->{type} = 'p';
+            },
+        },
+
         pre => {
             match => qr/^(?m:^\.pre\ *\n)((?:.*\n)*?)(?m:^\.pre\ *\n)(?:\s*\n)?/,
         },
